@@ -1,7 +1,10 @@
 from abc import ABC, abstractmethod
 from typing import List, Tuple
+import neurograd as ng
 from neurograd.tensor import Tensor
 from neurograd import xp
+from neurograd.utils.memory import maybe_log_op_memory
+
 
 class Function(ABC):
     name = None
@@ -36,6 +39,15 @@ class Function(ABC):
         output_data = self.forward(*[inp.data for inp in processed_inputs])
         requires_grad = any(inp.requires_grad for inp in processed_inputs)
         output = Tensor(output_data, requires_grad=requires_grad, grad_fn=self)
+        # Do memsave if ops has one
+        if hasattr(self, "_memsave") and getattr(self, "memsave", False):
+            self._memsave(self.parent_tensors, output)
+        # Optional per-op memory logging (enabled only inside MemoryMonitor)
+        try:
+            op_name = getattr(self, 'name', None) or self.__class__.__name__
+            maybe_log_op_memory(op_name, self.parent_tensors, output_data)
+        except Exception:
+            pass
         return output
     
     @abstractmethod
